@@ -1,6 +1,7 @@
 from time import sleep
 
-from kuyruk.kuyruk import Kuyruk, Task
+from kuyruk import Kuyruk, Task
+from kuyruk.events import task_prerun, task_postrun
 
 
 kuyruk = Kuyruk()
@@ -46,7 +47,7 @@ def rejecting_task():
     raise kuyruk.Reject
 
 
-@kuyruk.task
+@kuyruk.task(max_run_time=1)
 def sleeping_task(seconds):
     sleep(seconds)
 
@@ -61,33 +62,34 @@ def task_with_functions(message):
     return 42
 
 
-@kuyruk2.before_task
-def function1(task, args, kwargs):
+@kuyruk2.on_prerun
+def function1(sender, task, args, kwargs):
     print 'function1'
-    print task, args, kwargs
+    print sender, task, args, kwargs
+    assert sender is kuyruk2
     assert isinstance(task, Task)
     assert args == ['hello world']
     assert kwargs == {}
 
 
-@task_with_functions.before_task
-def function2(task, args, kwargs):
+@task_with_functions.on_prerun
+def function2(sender, task, args, kwargs):
     print 'function2'
 
 
-@task_with_functions.on_return
-def function3(task, args, kwargs, return_value):
+@task_with_functions.on_success
+def function3(sender, task, args, kwargs, return_value):
     print 'function3'
     assert return_value == 42
 
 
-@task_with_functions.after_task
-def function4(task, args, kwargs):
+@task_with_functions.on_postrun
+def function4(sender, task, args, kwargs):
     print 'function4'
 
 
-@kuyruk2.after_task
-def function5(task, args, kwargs):
+@kuyruk2.on_postrun
+def function5(sender, task, args, kwargs):
     print 'function5'
 
 
@@ -108,3 +110,29 @@ class Cat(object):
     @kuyruk.task
     def meow(self, message):
         print "Felix says:", message
+
+
+class DatabaseTask(Task):
+
+    def setup(self):
+        self.connect_signal(task_prerun, self.open_session)
+        self.connect_signal(task_postrun, self.close_session)
+
+    def open_session(self, sender, task, args, kwargs):
+        print 'Opening session'
+        self.session = object()
+
+    def close_session(self, sender, task, args, kwargs):
+        print 'Closing session'
+        self.session = None
+
+
+@kuyruk.task(task_class=DatabaseTask)
+def use_session():
+    print use_session.session
+
+
+@kuyruk.task
+def spawn_process(args=['sleep', '60']):
+    import subprocess
+    subprocess.check_call(args)
